#!/usr/bin/env python3
"""Compare pictures after they have been registered.

This script lists all the pictures in a directory, and shows each image
and the following one blended together.
A trackbar allows to change the blend weights.

The script uses natsorted because initially I forgot to add leading
zeros. If you have them, you can use sorted, instead.

Written in November 2021 by
Pier Angelo Vendrame <vogliadifarniente@gmail.com>.

To the extent possible under law, the author has dedicated all
copyright and related and neighboring rights to this software to the
public domain worldwide. This software is distributed without any
warranty.
"""

from glob import glob

import cv2
from natsort import natsorted

frames = natsorted(glob('worked/*.jpg'))
im1 = None
im2 = None


def load(idx):
    global im1, im2
    print(frames[idx], frames[idx + 1])
    im1 = cv2.imread(frames[idx])
    im2 = cv2.imread(frames[idx + 1])
    cv2.imshow('Im1', im1)
    cv2.imshow('Im2', im2)


def show(level):
    beta = level / 1000
    im4 = cv2.addWeighted(im1, 1 - beta, im2, beta, 0)
    cv2.imshow('Overlapped', im4)


cv2.namedWindow('Im1', cv2.WINDOW_NORMAL)
cv2.namedWindow('Im2', cv2.WINDOW_NORMAL)
cv2.namedWindow('Overlapped', cv2.WINDOW_NORMAL)
cv2.createTrackbar('Alpha', 'Overlapped', 500, 1000, show)

for i in range(len(frames) - 1):
    load(i)
    show(500)
    if cv2.waitKey(0) == 27:
        break
