#!/usr/bin/env python3
"""Create a video by taking pictures from a directory.

The transition between two images is created linearly blending them.
You can adjust the length of the transition and the output FPS.

Written in November 2021 by
Pier Angelo Vendrame <vogliadifarniente@gmail.com>.

To the extent possible under law, the author has dedicated all
copyright and related and neighboring rights to this software to the
public domain worldwide. This software is distributed without any
warranty.
"""
from glob import glob

import cv2
from natsort import natsorted


# keep is the number of frames that a transition lasts
# fps = 24
# keep = 5
fps = 60
keep = 15


frames = natsorted(glob('worked/*.jpg'))

# Adapt crop window (and size)
cut = (625, 750, 625 + 1755, 750 + 3120)
# size = (1280, 720)
size = (2560, 1440)


def read_im(name):
    im = cv2.imread(name)
    im = im[cut[0]:cut[2], cut[1]:cut[3]]
    im = cv2.resize(im, size)
    return im


im = read_im(frames[0])
cv2.imshow('Frame', im)
cv2.waitKey(1)


# h, w = im.shape[:2]
w, h = size
# You can change the codec with something else.
# I preferred motion JPEG because video creation was faster.
fourcc = cv2.VideoWriter_fourcc('M', 'J', 'P', 'G')
writer = cv2.VideoWriter('video.avi', fourcc, fps, (w, h))

for i in range(keep):
    writer.write(im)

for i, name in enumerate(frames[1:]):
    print(i, name)
    im_next = read_im(name)
    for i in range(keep):
        beta = i / keep
        alpha = 1 - beta
        frame = cv2.addWeighted(im, alpha, im_next, beta, 0)

        writer.write(frame)
        cv2.imshow('Frame', frame)
        cv2.waitKey(1)

    im = im_next

for i in range(keep):
    writer.write(im)

writer.release()
