#!/usr/bin/env python3
"""Register all frames to the first one.

This script takes images from a directory, and tries to register them
to the first one.
It uses SIFT to find matching points and findHomography to find the
transformation.

Written in November 2021 by
Pier Angelo Vendrame <vogliadifarniente@gmail.com>.

To the extent possible under law, the author has dedicated all
copyright and related and neighboring rights to this software to the
public domain worldwide. This software is distributed without any
warranty.
"""
from glob import glob
import random

import cv2

from sift import find_homography


frames = sorted(glob('zoom/*.jpg'))
border_size = 500

im = cv2.imread(frames[0])
if border_size > 0:
    im = cv2.copyMakeBorder(
        im, top=border_size, bottom=border_size, left=border_size,
        right=border_size, borderType=cv2.BORDER_CONSTANT, value=[0, 0, 0])
    cv2.imwrite('worked/im_0.jpg', im)
targets = [im]
im_next = None

targets = []
for i in range(5):
    num = random.randrange(i * 50, (i + 1) * 50)
    print(num)
    im = cv2.imread('worked/im_{}.jpg'.format(num))
    targets.append(im)


def show(level):
    beta = level / 1000
    im4 = cv2.addWeighted(targets[-1], 1 - beta, im_next, beta, 0)
    cv2.imshow('Overlapped', im4)


# cv2.namedWindow('Overlapped', cv2.WINDOW_NORMAL)
# cv2.createTrackbar('Alpha', 'Overlapped', 500, 1000, show)

for i in range(1, len(frames)):
    print(f'Working on {frames[i]} ({i})')
    im_next = cv2.imread(frames[i])
    H = find_homography(im_next, targets)
    im_next = cv2.warpPerspective(im_next, H, (im.shape[1], im.shape[0]))
    # show(500)
    # if cv2.waitKey(0) == 27:
    #     break
    cv2.imwrite(f'worked/im_{i}.jpg', im_next)
    # targets.append(im_next)
    # if len(targets) > 5:
    #     targets.pop(0)
